@@ -53,6 +53,30 @@ class TestClient(SubversionTestCase):
         self.build_tree({"dc/foo": None})
         self.client.add("dc/foo")
 
+    def test_commit(self):
+        self.build_tree({"dc/foo": None})
+        self.client.add("dc/foo")
+        self.client.log_msg_func = lambda c: "Amessage"
+        self.client.commit(["dc"])
+        r = ra.RemoteAccess(self.repos_url)
+        revprops = r.rev_proplist(1)
+        self.assertEquals("Amessage", revprops["svn:log"])
+
+    def test_commit_start(self):
+        self.build_tree({"dc/foo": None})
+        self.client = client.Client(auth=ra.Auth([ra.get_username_provider()]),
+                log_msg_func=lambda c: "Bmessage")
+        self.client.add("dc/foo")
+        self.client.commit(["dc"])
+        r = ra.RemoteAccess(self.repos_url)
+        revprops = r.rev_proplist(1)
+        self.assertEquals("Bmessage", revprops["svn:log"])
+
+    def test_mkdir(self):
+        self.client.mkdir(["dc/foo"])
+        self.client.mkdir("dc/bar")
+        self.client.mkdir("dc/bla", revprops={"svn:log": "foo"})
+
     def test_export(self):
         self.build_tree({"dc/foo": "bla"})
         self.client.add("dc/foo")
@@ -66,12 +90,14 @@ class TestClient(SubversionTestCase):
         adm = wc.WorkingCopy(None, os.path.join(os.getcwd(), "dc"))
         e = adm.entry(os.path.join(os.getcwd(), "dc", "trunk"))
         self.assertEquals(e.kind, NODE_DIR)
+        self.assertEquals(e.revision, -1)
         adm2 = wc.WorkingCopy(None, os.path.join(os.getcwd(), "dc", "trunk"))
         e = adm2.entry(os.path.join(os.getcwd(), "dc", "trunk", "foo"))
         self.assertEquals(e.kind, NODE_FILE)
+        self.assertEquals(e.revision, 0)
 
     def test_get_config(self):
-        self.assertIsInstance(client.get_config().__dict__, dict)
+        self.assertIsInstance(client.get_config(), client.Config)
 
     def test_diff(self):
         r = ra.RemoteAccess(self.repos_url,
